---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

# Bug Report

**!WARN!: If your browser does not correspond to the dependencies (see [README.md](README.md) file for more info), it may not work !**

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop / Browser / Python:**
 - OS: [e.g. iOS, Windows, Linux]
 - Python Version [e.g. 3.7.5, 3.9.10, 3.8.10]
 - Browser Version [e.g. Chrome101.0.4951.67, Opera87.0.4390.58, Safari537.36, Mozilla5.0]

**Additional context**
Add any other context about the problem here.